<div id="{{ name }}_editor" style="width: 100%"></div>

<textarea id="id_{{ name }}" name="{{ name }}" required="" style="display: none">
  {{ data }}
</textarea>

<script>
  document.addEventListener("DOMContentLoaded", function () {
    djangoReactiveRenderForm(
      "{{ name }}",
      {{ schema|safe }},
      {{ ui_schema|safe }},
      {{ data|safe }}
    );
  });
</script>
